emacs-bug-tracker
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[debbugs-tracker] bug#10069: closed (colour -> color spelling change)


From: GNU bug Tracking System
Subject: [debbugs-tracker] bug#10069: closed (colour -> color spelling change)
Date: Mon, 05 Mar 2018 01:43:02 +0000

Your message dated Sun, 4 Mar 2018 17:42:16 -0800
with message-id <address@hidden>
and subject line Re: colour -> color spelling change
has caused the debbugs.gnu.org bug report #10069,
regarding colour -> color spelling change
to be marked as done.

(If you believe you have received this mail in error, please contact
address@hidden)


-- 
10069: http://debbugs.gnu.org/cgi/bugreport.cgi?bug=10069
GNU Bug Tracking System
Contact address@hidden with problems
--- Begin Message --- Subject: colour -> color spelling change Date: Wed, 16 Nov 2011 23:39:00 -0800 User-agent: Mozilla/5.0 (X11; Linux i686; rv:7.0.1) Gecko/20110929 Thunderbird/7.0.1
Tags: patch
Severity: minor

Emacs consistently uses the American spelling "color" instead
of the British "colour", except for one or two modules.  Here's
a patch to fix this inconsistency.  This introduces an API change
so it should wait until after 24.1 is out.

=== modified file 'lisp/ChangeLog'
--- lisp/ChangeLog      2011-11-16 21:32:46 +0000
+++ lisp/ChangeLog      2011-11-17 03:47:59 +0000
@@ -1,3 +1,15 @@
+2011-11-17  Paul Eggert  <address@hidden>
+
+       Consistently use the spelling "color".
+       * hfy-cmap.el (hfy-fallback-color-map):
+       Rename from hfy-fallback-colour-map.
+       (hfy-rgb-txt-color-map): Rename from hfy-rgb-txt-colour-map.
+       (hfy-fallback-color-values): Rename from hfy-fallback-colour-values.
+       * htmlfontify.el (hfy-color-vals): Rename from hfy-colour-vals.
+       (hfy-color): Rename from hfy-colour.
+       (hfy-box-to-border-assoc, hfy-box-to-style):
+       Spell it "color", not "colour", in strings.
+
 2011-11-16  Michael Albinus  <address@hidden>
 
        * net/tramp.el (tramp-handle-file-truename): Cache only the local

=== modified file 'lisp/hfy-cmap.el'
--- lisp/htmlfontify.el 2011-11-15 17:37:37 +0000
+++ lisp/htmlfontify.el 2011-11-17 02:06:14 +0000
@@ -566,22 +566,22 @@
       (if (memq elt set-b) (setq interq (cons elt interq))))
     interq))
 
-(defun hfy-colour-vals (colour)
-  "Where COLOUR is a color name or #XXXXXX style triplet, return a
+(defun hfy-color-vals (color)
+  "Where COLOR is a color name or #XXXXXX style triplet, return a
 list of three (16 bit) rgb values for said color.\n
-If a window system is unavailable, calls `hfy-fallback-colour-values'."
-  (if (string-match hfy-triplet-regex colour)
+If a window system is unavailable, calls `hfy-fallback-color-values'."
+  (if (string-match hfy-triplet-regex color)
       (mapcar
-       (lambda (x) (* (string-to-number (match-string x colour) 16) 257))
+       (lambda (x) (* (string-to-number (match-string x color) 16) 257))
        '(1 2 3))
-    ;;(message ">> %s" colour)
+    ;;(message ">> %s" color)
     (if window-system
         (if (fboundp 'color-values)
-            (color-values colour)
+            (color-values color)
           ;;(message "[%S]" window-system)
-          (x-color-values colour))
-      ;; blarg - tty colours are no good - go fetch some X colours:
-      (hfy-fallback-colour-values colour))))
+          (x-color-values color))
+      ;; blarg - tty colors are no good - go fetch some X colors:
+      (hfy-fallback-color-values color))))
 
 (defvar hfy-cperl-mode-kludged-p nil)
 
@@ -719,7 +719,7 @@
   "Replace the end of a CSS style declaration STYLE-STRING with the contents
 of the variable `hfy-src-doc-link-style', removing text matching the regex
 `hfy-src-doc-link-unstyle' first, if necessary."
-  ;;(message "hfy-colour-vals");;DBUG
+  ;;(message "hfy-color-vals");;DBUG
   (if (string-match hfy-src-doc-link-unstyle style-string)
       (setq style-string (replace-match "" 'fixed-case 'literal style-string)))
   (if (and (not (string-match hfy-src-doc-link-style style-string))
@@ -732,15 +732,15 @@
 
 ;; utility functions - cast emacs style specification values into their
 ;; css2 equivalents:
-(defun hfy-triplet (colour)
-  "Takes a COLOUR name (string) and return a CSS rgb(R, G, B) triplet string.
+(defun hfy-triplet (color)
+  "Takes a COLOR name (string) and return a CSS rgb(R, G, B) triplet string.
 Uses the definition of \"white\" to map the numbers to the 0-255 range, so
 if you've redefined white, (esp. if you've redefined it to have a triplet
 member lower than that of the color you are processing) strange things
 may happen."
-  ;;(message "hfy-colour-vals");;DBUG
-  (let ((white (mapcar (lambda (I) (float (1+ I))) (hfy-colour-vals "white")))
-        (rgb16 (mapcar (lambda (I) (float (1+ I))) (hfy-colour-vals  colour))))
+  ;;(message "hfy-color-vals");;DBUG
+  (let ((white (mapcar (lambda (I) (float (1+ I))) (hfy-color-vals "white")))
+        (rgb16 (mapcar (lambda (I) (float (1+ I))) (hfy-color-vals  color))))
     (if rgb16
         ;;(apply 'format "rgb(%d, %d, %d)"
         ;; Use #rrggbb instead, it is smaller
@@ -751,8 +751,8 @@
                        '(0 1 2))))))
 
 (defun hfy-family (family) (list (cons "font-family"  family)))
-(defun hfy-bgcol  (colour) (list (cons "background"   (hfy-triplet colour))))
-(defun hfy-colour (colour) (list (cons "color"        (hfy-triplet colour))))
+(defun hfy-bgcol  (color)  (list (cons "background"   (hfy-triplet color))))
+(defun hfy-color  (color)  (list (cons "color"        (hfy-triplet color))))
 (defun hfy-width  (width)  (list (cons "font-stretch" (symbol-name  width))))
 
 (defcustom hfy-font-zoom 1.05
@@ -800,17 +800,17 @@
       (let ((tag (car  spec))
             (val (cadr spec)))
         (cons (case tag
-                (:color (cons "colour" val))
-                (:width (cons "width"  val))
-                (:style (cons "style"  val)))
+                (:color (cons "color" val))
+                (:width (cons "width" val))
+                (:style (cons "style" val)))
               (hfy-box-to-border-assoc (cddr spec))))))
 
 (defun hfy-box-to-style (spec)
   (let* ((css (hfy-box-to-border-assoc  spec))
-         (col (cdr      (assoc "colour" css)))
+         (col (cdr      (assoc "color"  css)))
          (s   (cdr      (assoc "style"  css))))
     (list
-     (if col (cons "border-color" (cdr (assoc "colour" css))))
+     (if col (cons "border-color" (cdr (assoc "color" css))))
      (cons "border-width" (format "%dpx" (or (cdr (assoc "width" css)) 1)))
      (cons "border-style" (case s
                             (released-button "outset")
@@ -989,7 +989,7 @@
                        (:width          (hfy-width     val))
                        (:weight         (hfy-weight    val))
                        (:slant          (hfy-slant     val))
-                       (:foreground     (hfy-colour    val))
+                       (:foreground     (hfy-color     val))
                        (:background     (hfy-bgcol     val))
                        (:box            (hfy-box       val))
                        (:height         (hfy-size      val))
@@ -2314,22 +2314,22 @@
     (load file 'NOERROR nil nil) ))
 
 
-;;;### (autoloads (hfy-fallback-colour-values htmlfontify-load-rgb-file)
-;;;;;;  "hfy-cmap" "hfy-cmap.el" "8dce008297f15826cc6ab82203c46fa6")
+;;;### (autoloads (hfy-fallback-color-values htmlfontify-load-rgb-file)
+;;;;;;  "hfy-cmap" "hfy-cmap.el" "2e7bc2fe079a42e70fb284e070d001f1")
 ;;; Generated autoloads from hfy-cmap.el
 
 (autoload 'htmlfontify-load-rgb-file "hfy-cmap" "\
 Load an X11 style rgb.txt FILE.
 Search `hfy-rgb-load-path' if FILE is not specified.
-Loads the variable `hfy-rgb-txt-colour-map', which is used by
-`hfy-fallback-colour-values'.
+Loads the variable `hfy-rgb-txt-color-map', which is used by
+`hfy-fallback-color-values'.
 
 \(fn &optional FILE)" t nil)
 
-(autoload 'hfy-fallback-colour-values "hfy-cmap" "\
+(autoload 'hfy-fallback-color-values "hfy-cmap" "\
 Use a fallback method for obtaining the rgb values for a color.
 
-\(fn COLOUR-STRING)" nil nil)
+\(fn COLOR-STRING)" nil nil)
 
 ;;;***
 




--- End Message ---
--- Begin Message --- Subject: Re: colour -> color spelling change Date: Sun, 4 Mar 2018 17:42:16 -0800 User-agent: Mozilla/5.0 (X11; Linux x86_64; rv:52.0) Gecko/20100101 Thunderbird/52.6.0
I installed the attached patch into master and am closing this bug report.

Attachment: 0001-Spelling-fixes-Bug-10068.patch
Description: Text Data


--- End Message ---

reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- lisp/hfy-cmap.el    2011-01-25 04:08:28 +0000
+++ lisp/hfy-cmap.el    2011-11-17 02:04:05 +0000
@@ -1,4 +1,4 @@
 ;;; hfy-cmap.el --- Fallback colour name -> rgb mapping for `htmlfontify'
 
 ;; Copyright (C) 2002-2003, 2009-2011  Free Software Foundation, Inc.
 
@@ -6,11 +6,11 @@
 ;; Package: htmlfontify
 ;; Filename: hfy-cmap.el
 ;; Version: 0.20
 ;; Keywords: colour, rgb
 ;; Author: Vivek Dasmohapatra <address@hidden>
 ;; Maintainer: Vivek Dasmohapatra <address@hidden>
 ;; Created: 2002-01-20
 ;; Description: fallback code for colour name -> rgb mapping
 ;; URL: http://rtfm.etla.org/emacs/htmlfontify/
 ;; Last-Updated: Sat 2003-02-15 03:49:32 +0000
 ;; Package: htmlfontify
@@ -34,7 +34,7 @@
 
 ;;; Code:
 
-(defconst hfy-fallback-colour-map
+(defconst hfy-fallback-color-map
   '(("snow"                    65535 64250 64250)
     ("ghost white"             63736 63736 65535)
     ("GhostWhite"              63736 63736 65535)
@@ -788,7 +788,7 @@
     ("light green"             37008 61166 37008)
     ("LightGreen"              37008 61166 37008)) )
 
-(defvar hfy-rgb-txt-colour-map nil)
+(defvar hfy-rgb-txt-color-map nil)
 
 (defvar hfy-rgb-load-path
   (list "/etc/X11"
@@ -808,8 +808,8 @@
 (defun htmlfontify-load-rgb-file (&optional file)
   "Load an X11 style rgb.txt FILE.
 Search `hfy-rgb-load-path' if FILE is not specified.
-Loads the variable `hfy-rgb-txt-colour-map', which is used by
-`hfy-fallback-colour-values'."
+Loads the variable `hfy-rgb-txt-color-map', which is used by
+`hfy-fallback-color-values'."
   (interactive
    (list
     (read-file-name "rgb.txt \(equivalent\) file: " "" nil t (hfy-rgb-file))))
@@ -824,25 +824,25 @@
          (htmlfontify-unload-rgb-file)
          (while (/= end-of-rgb 1)
            (if (looking-at hfy-rgb-regex)
-               (setq hfy-rgb-txt-colour-map
+               (setq hfy-rgb-txt-color-map
                      (cons (list (match-string 4)
                                  (string-to-number (match-string 1))
                                  (string-to-number (match-string 2))
                                  (string-to-number (match-string 3)))
-                           hfy-rgb-txt-colour-map)) )
+                           hfy-rgb-txt-color-map)) )
            (setq end-of-rgb (forward-line)))
          (kill-buffer rgb-buffer)))))
 
 (defun htmlfontify-unload-rgb-file ()
   "Unload the current color name -> rgb translation map."
   (interactive)
-  (setq hfy-rgb-txt-colour-map nil))
+  (setq hfy-rgb-txt-color-map nil))
 
 ;;;###autoload
-(defun hfy-fallback-colour-values (colour-string)
+(defun hfy-fallback-color-values (color-string)
   "Use a fallback method for obtaining the rgb values for a color."
-  (cdr (assoc-string colour-string (or hfy-rgb-txt-colour-map
-                                       hfy-fallback-colour-map))) )
+  (cdr (assoc-string color-string (or hfy-rgb-txt-color-map
+                                       hfy-fallback-color-map))) )
 
 (provide 'hfy-cmap)
 
@@ -1,4 +1,4 @@
-;;; hfy-cmap.el --- Fallback colour name -> rgb mapping for `htmlfontify'
+;;; hfy-cmap.el --- Fallback color name -> rgb mapping for `htmlfontify'
 
 ;; Copyright (C) 2002-2003, 2009-2011  Free Software Foundation, Inc.
@@ -6,11 +6,11 @@
 ;; Filename: hfy-cmap.el
 ;; Version: 0.20
-;; Keywords: colour, rgb
+;; Keywords: color, colour, rgb
 ;; Author: Vivek Dasmohapatra <address@hidden>
 ;; Maintainer: Vivek Dasmohapatra <address@hidden>
@@ -6,11 +6,11 @@
 ;; Maintainer: Vivek Dasmohapatra <address@hidden>
 ;; Created: 2002-01-20
-;; Description: fallback code for colour name -> rgb mapping
+;; Description: fallback code for color name -> rgb mapping
 ;; URL: http://rtfm.etla.org/emacs/htmlfontify/
 ;; Last-Updated: Sat 2003-02-15 03:49:32 +0000

=== modified file 'lisp/htmlfontify.el'